@@ -19,16 +19,19 @@ if [[ ${LOCAL} != true ]]; then
     fi
 fi
 
-echo ${CFLAGS}
+echo "Cekit build flags : ${CFLAGS}"
 
 OLMDIR=deploy/olm-catalog/prod
-CSV=businessautomation-operator.${CSVVERSION}.clusterserviceversion.yaml
+CSV=businessautomation-operator.clusterserviceversion.yaml
 if [[ ${DEV} == true ]]; then
     OLMDIR=deploy/olm-catalog/dev
-    BUNDLE_NAME=quay.io/tchughesiv/${BUNDLE}
+    BUNDLE_NAME=quay.io/${USERNAME}/${BUNDLE}
 fi
 VERDIR=${OLMDIR}/${CSVVERSION}
 
+echo "Building bundle operator image version ${CSVVERSION}"
+
+
 CRD=kieapp.crd.yaml
 #if (( $(echo "${VERSION} 7.9.0" | awk '{print ($1 < $2)}') )); then
 #    CRD=kieapp.crd.v1beta1.yaml
@@ -58,13 +61,14 @@ if [[ ${LOCAL} != true ]]; then
         --overrides '{
     "osbs":
         {
-        "extra_dir": '${VERDIR}',
+        "extra_dir": '${VERDIR}/',
+        "extra_dir_target": "/",
         "configuration":
             {
             "container":
                 {
                 "operator_manifests":
-                    {"enable_digest_pinning": true, "enable_repo_replacements": true, "enable_registry_replacements": true, "manifests_dir": "manifests"},
+                    {"enable_digest_pinning": true, "enable_repo_replacements": true, "enable_registry_replacements": true, "manifests_dir": '${VERDIR}/manifests'},
                 "platforms":
                     {"only": ["x86_64"]}
                 }
@@ -73,11 +77,6 @@ if [[ ${LOCAL} != true ]]; then
             {"name": "containers/rhpam-operator-bundle", "branch": "rhba-stable-rhel-8"}
         }
     }' \
-        --overrides '{
-    artifacts: [
-        {name: '${CRD}', path: '${CRD_PATH}', md5: '${MD5_CRD}', dest: '/manifests'},
-        {name: '${ANNO}', path: '${ANNO_PATH}', md5: '${MD5_ANNO}', dest: '/metadata'}
-    ]}' \
         ${CFLAGS}
 else
     cekit -v --descriptor image-bundle.yaml --redhat build \
@@ -85,9 +84,9 @@ else
         --overrides '{version: '${VERSION}'}' \
         --overrides '{
     artifacts: [
-        {name: '${CSV}', path: '${CSV_PATH}', md5: '${MD5_CSV}', dest: '/manifests'},
-        {name: '${CRD}', path: '${CRD_PATH}', md5: '${MD5_CRD}', dest: '/manifests'},
-        {name: '${ANNO}', path: '${ANNO_PATH}', md5: '${MD5_ANNO}', dest: '/metadata'}
+        {name: '${CSV}', path: '${CSV_PATH}', md5: '${MD5_CSV}', dest: '/manifests/'},
+        {name: '${CRD}', path: '${CRD_PATH}', md5: '${MD5_CRD}', dest: '/manifests/'},
+        {name: '${ANNO}', path: '${ANNO_PATH}', md5: '${MD5_ANNO}', dest: '/metadata/'}
     ]}' \
         ${CFLAGS}
 fi
\ No newline at end of file
