@@ -27,6 +27,8 @@ type KieAppSpec struct {
 	Upgrades KieAppUpgrades `json:"upgrades,omitempty"`
 	// Set true to enable image tags, disabled by default. This will leverage image tags instead of the image digests.
 	UseImageTags bool `json:"useImageTags,omitempty"`
+	// Defines which truststore is used by the console, kieservers, smartrouter, and dashbuilder
+	Truststore *KieAppTruststore `json:"truststore,omitempty"`
 	// The version of the application deployment.
 	Version      string            `json:"version,omitempty"`
 	CommonConfig CommonConfig      `json:"commonConfig,omitempty"`
@@ -67,6 +69,12 @@ type KieAppRegistry struct {
 	Insecure bool `json:"insecure,omitempty"`
 }
 
+// KieAppTruststore defines which truststore is used by the console, kieservers, smartrouter, and dashbuilder
+type KieAppTruststore struct {
+	// Set true to use Openshift's CA Bundle as a truststore, instead of java's cacert.
+	OpenshiftCaBundle bool `json:"openshiftCaBundle,omitempty"`
+}
+
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
 
 // KieApp is the Schema for the kieapps API
@@ -129,6 +137,9 @@ type KieServerSet struct {
 	Database     *DatabaseObject  `json:"database,omitempty"`
 	Jms          *KieAppJmsObject `json:"jms,omitempty"`
 	Jvm          *JvmObject       `json:"jvm,omitempty"`
+	// JbpmCluster Enable the KIE Server Jbpm clustering for processes fail-over, it could increase the number of kieservers
+	JbpmCluster bool            `json:"jbpmCluster,omitempty"`
+	Kafka       *KafkaExtObject `json:"kafka,omitempty"`
 }
 
 // ConsoleObject configuration of the RHPAM workbench
@@ -155,7 +166,8 @@ type SmartRouterObject struct {
 	// Smart Router protocol, if no value is provided, http is the default protocol.
 	Protocol string `json:"protocol,omitempty"`
 	// If enabled, Business Central will use the external smartrouter route to communicate with it. Note that, valid SSL certificates should be used.
-	UseExternalRoute bool `json:"useExternalRoute,omitempty"`
+	UseExternalRoute bool       `json:"useExternalRoute,omitempty"`
+	Jvm              *JvmObject `json:"jvm,omitempty"`
 }
 
 // KieAppJmsObject messaging specification to be used by the KieApp
@@ -588,15 +600,16 @@ type OpenShiftObject interface {
 }
 
 type EnvTemplate struct {
-	*CommonConfig    `json:",inline"`
-	Console          ConsoleTemplate          `json:"console,omitempty"`
-	Servers          []ServerTemplate         `json:"servers,omitempty"`
-	SmartRouter      SmartRouterTemplate      `json:"smartRouter,omitempty"`
-	Auth             AuthTemplate             `json:"auth,omitempty"`
-	ProcessMigration ProcessMigrationTemplate `json:"processMigration,omitempty"`
-	Dashbuilder      DashbuilderTemplate      `json:"dashbuilder,omitempty"`
-	Databases        []DatabaseTemplate       `json:"databases,omitempty"`
-	Constants        TemplateConstants        `json:"constants,omitempty"`
+	*CommonConfig     `json:",inline"`
+	Console           ConsoleTemplate          `json:"console,omitempty"`
+	Servers           []ServerTemplate         `json:"servers,omitempty"`
+	SmartRouter       SmartRouterTemplate      `json:"smartRouter,omitempty"`
+	Auth              AuthTemplate             `json:"auth,omitempty"`
+	ProcessMigration  ProcessMigrationTemplate `json:"processMigration,omitempty"`
+	Dashbuilder       DashbuilderTemplate      `json:"dashbuilder,omitempty"`
+	Databases         []DatabaseTemplate       `json:"databases,omitempty"`
+	Constants         TemplateConstants        `json:"constants,omitempty"`
+	OpenshiftCaBundle bool                     `json:"openshiftCaBundle,omitempty"`
 }
 
 // TemplateConstants constant values that are used within the different configuration templates
@@ -660,6 +673,9 @@ type ServerTemplate struct {
 	SmartRouter      SmartRouterObject `json:"smartRouter,omitempty"`
 	Jvm              JvmObject         `json:"jvm,omitempty"`
 	StorageClassName string            `json:"storageClassName,omitempty"`
+	// JbpmCluster Enable the KIE Server Jbpm clustering for processes fail-over, it could increase the number of kieservers
+	JbpmCluster bool            `json:"jbpmCluster,omitempty"`
+	Kafka       *KafkaExtObject `json:"kafka,omitempty"`
 }
 
 // DashbuilderTemplate contains all the variables used in the yaml templates
@@ -758,16 +774,17 @@ type DatabaseTemplate struct {
 
 // SmartRouterTemplate contains all the variables used in the yaml templates
 type SmartRouterTemplate struct {
-	OmitImageStream  bool   `json:"omitImageStream"`
-	Replicas         int32  `json:"replicas,omitempty"`
-	KeystoreSecret   string `json:"keystoreSecret,omitempty"`
-	Protocol         string `json:"protocol,omitempty"`
-	UseExternalRoute bool   `json:"useExternalRoute,omitempty"`
-	ImageContext     string `json:"imageContext,omitempty"`
-	Image            string `json:"image,omitempty"`
-	ImageTag         string `json:"imageTag,omitempty"`
-	ImageURL         string `json:"imageURL,omitempty"`
-	StorageClassName string `json:"storageClassName,omitempty"`
+	OmitImageStream  bool      `json:"omitImageStream"`
+	Replicas         int32     `json:"replicas,omitempty"`
+	KeystoreSecret   string    `json:"keystoreSecret,omitempty"`
+	Protocol         string    `json:"protocol,omitempty"`
+	UseExternalRoute bool      `json:"useExternalRoute,omitempty"`
+	ImageContext     string    `json:"imageContext,omitempty"`
+	Image            string    `json:"image,omitempty"`
+	ImageTag         string    `json:"imageTag,omitempty"`
+	ImageURL         string    `json:"imageURL,omitempty"`
+	StorageClassName string    `json:"storageClassName,omitempty"`
+	Jvm              JvmObject `json:"jvm,omitempty"`
 }
 
 // ReplicaConstants contains the default replica amounts for a component in a given environment type
@@ -942,6 +959,24 @@ type ObjectReference struct {
 	FieldPath string `json:"fieldPath,omitempty" protobuf:"bytes,7,opt,name=fieldPath"`
 }
 
+// KafkaExtObject kafka configuration to be used by the KieApp
+type KafkaExtObject struct {
+	// Contains the mapping message/signal=topicName for every topic that needs to be mapped globally
+	Topics []string `json:"topics,omitempty"`
+	// A comma separated list of host/port pairs to use for establishing the initial connection to the Kafka cluster
+	BootstrapServers string `json:"bootstrapServers,omitempty"`
+	// Identifier to pass to the server when making requests
+	ClientID string `json:"clientID,omitempty"`
+	// Allow automatic topic creation.
+	AutocreateTopics *bool `json:"autocreateTopics,omitempty"`
+	// Group identifier the group this consumer belongs
+	GroupID string `json:"groupID,omitempty"`
+	// The number of acknowledgments the producer requires the leader to have received before considering a request complete.
+	Acks *int `json:"acks,omitempty"`
+	// Number of milliseconds that indicates how long publish method will bloc
+	MaxBlockMs *int32 `json:"maxBlockMs,omitempty"`
+}
+
 func init() {
 	SchemeBuilder.Register(&KieApp{}, &KieAppList{})
 }
