@@ -2,28 +2,63 @@ package constants
 
 import (
 	api "github.com/kiegroup/kie-cloud-operator/pkg/apis/app/v2"
+	"golang.org/x/mod/semver"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
+// Ocp4Versions - OpenShift minor versions used for image curation
+var Ocp4Versions = []string{"4.7", "4.6"}
+
 const (
 	// CurrentVersion product version supported
-	CurrentVersion = "7.10.0"
-	// PriorVersion1 product version supported
-	PriorVersion1 = "7.9.1"
-	// PriorVersion2 product version supported
-	PriorVersion2 = "7.9.0"
+	CurrentVersion = "7.11.0"
+	// PriorVersion product version supported
+	PriorVersion = "7.10.1"
 )
 
 // SupportedVersions - product versions this operator supports
-var SupportedVersions = []string{CurrentVersion, PriorVersion1, PriorVersion2}
+var SupportedVersions = []string{CurrentVersion, PriorVersion}
 
-// Ocp4Versions - OpenShift minor versions used for image curation
-var Ocp4Versions = []string{"4.6", "4.5", "4.4", "4.3", "4.2", "4.1"}
+// VersionConstants ...
+var VersionConstants = map[string]*api.VersionConfigs{
+	CurrentVersion: {
+		APIVersion:          api.SchemeGroupVersion.Version,
+		OseCliImageURL:      OseCli4ImageURL,
+		OseCliComponent:     OseCli4Component,
+		BrokerImage:         BrokerImage,
+		BrokerImageTag:      Broker78ImageTag,
+		BrokerImageURL:      Broker78ImageURL,
+		DatagridImage:       Datagrid73Image,
+		DatagridImageTag:    Datagrid73ImageTag16,
+		DatagridImageURL:    Datagrid73ImageURL16,
+		DatagridComponent:   Datagrid73Component,
+		MySQLImageURL:       MySQL80ImageURL,
+		MySQLComponent:      MySQL80Component,
+		PostgreSQLImageURL:  PostgreSQL10ImageURL,
+		PostgreSQLComponent: PostgreSQL10Component,
+	},
+	PriorVersion: {
+		APIVersion:          api.SchemeGroupVersion.Version,
+		OseCliImageURL:      OseCli4ImageURL,
+		OseCliComponent:     OseCli4Component,
+		BrokerImage:         BrokerImage,
+		BrokerImageTag:      Broker78ImageTag,
+		BrokerImageURL:      Broker78ImageURL,
+		DatagridImage:       Datagrid73Image,
+		DatagridImageTag:    Datagrid73ImageTag16,
+		DatagridImageURL:    Datagrid73ImageURL16,
+		DatagridComponent:   Datagrid73Component,
+		MySQLImageURL:       MySQL80ImageURL,
+		MySQLComponent:      MySQL80Component,
+		PostgreSQLImageURL:  PostgreSQL10ImageURL,
+		PostgreSQLComponent: PostgreSQL10Component,
+	},
+}
 
 const (
 	// ProductName used for metering labels
-	ProductName = "process-automation"
+	ProductName = "Red_Hat_Process_Automation"
 	// LabelRHproductName used as metering label
 	LabelRHproductName = "rht.prod_name"
 	// LabelRHproductVersion used as metering label
@@ -85,6 +120,16 @@ const (
 	KeystoreAlias = "jboss"
 	// KeystoreName used when creating Secret
 	KeystoreName = "keystore.jks"
+	// TruststoreSecret is the default format for truststore secret names
+	TruststoreSecret = "-truststore"
+	// TruststoreName used when creating Secret
+	TruststoreName = "truststore.jks"
+	// TruststorePath used when mounting Secret
+	TruststorePath = "/etc/openshift-truststore-volume"
+	// TruststorePwd used when creating Secret
+	TruststorePwd = "changeit"
+	// CaBundleKey ...
+	CaBundleKey = "ca-bundle.crt"
 	// DatabaseVolumeSuffix Suffix to use for any database volume and volumeMounts
 	DatabaseVolumeSuffix = "pvol"
 	// DefaultDatabaseSize Default Database Persistence size
@@ -134,7 +179,6 @@ const (
 	PamSmartRouterVar      = relatedImageVar + "PAM_SMARTROUTER_IMAGE_"
 
 	OauthVar             = relatedImageVar + "OAUTH_PROXY_IMAGE_"
-	Oauth3ImageLatestURL = ImageRegistry + "/openshift3/oauth-proxy:latest"
 	Oauth4ImageURL       = ImageRegistry + "/openshift4/ose-oauth-proxy"
 	Oauth4ImageLatestURL = Oauth4ImageURL + ":latest"
 	OauthComponent       = "golang-github-openshift-oauth-proxy-container"
@@ -149,9 +193,8 @@ const (
 	MySQL80ImageURL  = ImageRegistry + "/rhscl/mysql-80-rhel7:latest"
 	MySQL80Component = "rh-mysql80-container"
 
-	OseCliVar          = relatedImageVar + "OSE_CLI_IMAGE_"
-	OseCli311ImageURL  = ImageRegistry + "/openshift3/ose-cli:v3.11"
-	OseCli311Component = "openshift-enterprise-cli-container"
+	OseCliVar        = relatedImageVar + "OSE_CLI_IMAGE_"
+	OseCli4Component = "openshift-enterprise-cli-container"
 
 	BrokerComponent = "amq-broker-openshift-container"
 	BrokerVar       = relatedImageVar + "BROKER_IMAGE_"
@@ -182,7 +225,7 @@ const (
 	ConsoleProdMemLimit         = "2Gi"
 	ConsoleAuthoringCPULimit    = "2"
 	ConsoleAuthoringMemLimit    = "4Gi"
-	ConsoleAuthoringCPURequests = "1536Mi"
+	ConsoleAuthoringCPURequests = "1500m"
 	ConsoleAuthoringMemRequests = "3Gi"
 	ConsoleProdCPURequests      = "500m"
 	ConsoleProdMemRequests      = "1536Mi"
@@ -206,8 +249,33 @@ const (
 	RhpamControllerImageName  = RhpamPrefix + "-controller-" + RhelVersion
 	RhdmSmartRouterImageName  = RhdmPrefix + "-smartrouter-" + RhelVersion
 	RhdmControllerImageName   = RhdmPrefix + "-controller-" + RhelVersion
+
+	RhdmDecisionCentral     = "decisioncentral"
+	RhpamBusinessCentral    = "businesscentral"
+	RhpamBusinessCentralMon = "businesscentral-monitoring"
+
+	DashBuilder      = "dashbuilder"
+	Smartrouter      = "smartrouter"
+	ProcessMigration = "process-migration"
+	Production       = "production"
+
+	SUBCOMPONENT_TYPE_APP   = "application"
+	SUBCOMPONENT_TYPE_INFRA = "infrastructure"
+
+	//Labels for Kube_ping
+	ClusterLabel       = "cluster"
+	ClusterLabelPrefix = "jgrp.k8s."
+
+	//Envs
+	KubeNS     = "KUBERNETES_NAMESPACE"
+	KubeLabels = "KUBERNETES_LABELS"
+
+	//Kafka
+	KafkaTopicsEnv = "KIE_SERVER_KAFKA_EXT_TOPICS"
 )
 
+var OseCli4ImageURL = ImageRegistry + "/openshift4/ose-cli:" + highestOcpVersion(Ocp4Versions)
+
 // Console Resource Limits for BC Monitoring in Prod Env
 var ConsoleProdLimits = map[string]string{
 	"CPU": ConsoleProdCPULimit,
@@ -349,58 +417,6 @@ type ImageRefTag struct {
 	From *corev1.ObjectReference `json:"from"`
 }
 
-// VersionConstants ...
-var VersionConstants = map[string]*api.VersionConfigs{
-	CurrentVersion: {
-		APIVersion:          api.SchemeGroupVersion.Version,
-		OseCliImageURL:      OseCli311ImageURL,
-		OseCliComponent:     OseCli311Component,
-		BrokerImage:         BrokerImage,
-		BrokerImageTag:      Broker78ImageTag,
-		BrokerImageURL:      Broker78ImageURL,
-		DatagridImage:       Datagrid73Image,
-		DatagridImageTag:    Datagrid73ImageTag16,
-		DatagridImageURL:    Datagrid73ImageURL16,
-		DatagridComponent:   Datagrid73Component,
-		MySQLImageURL:       MySQL80ImageURL,
-		MySQLComponent:      MySQL80Component,
-		PostgreSQLImageURL:  PostgreSQL10ImageURL,
-		PostgreSQLComponent: PostgreSQL10Component,
-	},
-	PriorVersion1: {
-		APIVersion:          api.SchemeGroupVersion.Version,
-		OseCliImageURL:      OseCli311ImageURL,
-		OseCliComponent:     OseCli311Component,
-		BrokerImage:         BrokerImage,
-		BrokerImageTag:      Broker77ImageTag,
-		BrokerImageURL:      Broker77ImageURL,
-		DatagridImage:       Datagrid73Image,
-		DatagridImageTag:    Datagrid73ImageTag16,
-		DatagridImageURL:    Datagrid73ImageURL16,
-		DatagridComponent:   Datagrid73Component,
-		MySQLImageURL:       MySQL80ImageURL,
-		MySQLComponent:      MySQL80Component,
-		PostgreSQLImageURL:  PostgreSQL10ImageURL,
-		PostgreSQLComponent: PostgreSQL10Component,
-	},
-	PriorVersion2: {
-		APIVersion:          api.SchemeGroupVersion.Version,
-		OseCliImageURL:      OseCli311ImageURL,
-		OseCliComponent:     OseCli311Component,
-		BrokerImage:         BrokerImage,
-		BrokerImageTag:      Broker77ImageTag,
-		BrokerImageURL:      Broker77ImageURL,
-		DatagridImage:       Datagrid73Image,
-		DatagridImageTag:    Datagrid73ImageTag16,
-		DatagridImageURL:    Datagrid73ImageURL16,
-		DatagridComponent:   Datagrid73Component,
-		MySQLImageURL:       MySQL80ImageURL,
-		MySQLComponent:      MySQL80Component,
-		PostgreSQLImageURL:  PostgreSQL10ImageURL,
-		PostgreSQLComponent: PostgreSQL10Component,
-	},
-}
-
 var rhpamAppConstants = api.AppConstants{Product: RhpamPrefix, Prefix: "rhpamcentr", ImageName: "businesscentral", ImageVar: PamBusinessCentralVar, MavenRepo: "RHPAMCENTR", FriendlyName: "Business Central"}
 var rhpamMonitorAppConstants = api.AppConstants{Product: RhpamPrefix, Prefix: "rhpamcentrmon", ImageName: "businesscentral-monitoring", ImageVar: PamBCMonitoringVar, MavenRepo: "RHPAMCENTR", FriendlyName: "Business Central Monitoring"}
 var rhpamDashbuilderConstants = api.AppConstants{Product: RhpamPrefix, Prefix: "rhpamdash", ImageName: "dashbuilder", ImageVar: PamDashbuilderVar, FriendlyName: "Dashbuilder"}
@@ -472,3 +488,14 @@ var DebugFalse = corev1.EnvVar{
 	Name:  "DEBUG",
 	Value: "false",
 }
+
+func highestOcpVersion(versions []string) string {
+	highest := ""
+	for _, ver := range versions {
+		ver = "v" + ver
+		if semver.IsValid(ver) && semver.Compare(ver, highest) > 0 {
+			highest = ver
+		}
+	}
+	return highest
+}
