@@ -29,7 +29,14 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 )
 
-var log = logs.GetLogger("kieapp.defaults")
+var (
+	log          = logs.GetLogger("kieapp.defaults")
+	caOptsAppend = []string{
+		"-Djavax.net.ssl.trustStoreType=jks",
+		"-Djavax.net.ssl.trustStore=" + constants.TruststorePath + "/" + constants.TruststoreName,
+		"-Djavax.net.ssl.trustStorePassword=" + constants.TruststorePwd,
+	}
+)
 
 // GetEnvironment returns an Environment from merging the common config and the config
 // related to the environment set in the KieApp definition
@@ -134,40 +141,77 @@ func GetEnvironment(cr *api.KieApp, service kubernetes.PlatformService) (api.Env
 	if err != nil {
 		return api.Environment{}, err
 	}
+	overrideKafkaTopicsEnv(cr, &mergedEnv)
 	setProductLabels(cr, &mergedEnv)
 	return mergedEnv, nil
 }
 
 func setProductLabels(cr *api.KieApp, env *api.Environment) {
-	setObjectLabels(cr, &env.Console)
-	setObjectLabels(cr, &env.Dashbuilder)
+	setObjectLabels(cr, &env.Console, getFormattedComponentName(cr, getConsoleName(cr)))
+	setObjectLabels(cr, &env.Dashbuilder, getFormattedComponentName(cr, constants.DashBuilder))
 	for index := range env.Servers {
-		setObjectLabels(cr, &env.Servers[index])
+		setObjectLabelsForServer(cr, &env.Servers[index])
 	}
-	setObjectLabels(cr, &env.SmartRouter)
-	setObjectLabels(cr, &env.ProcessMigration)
+	setObjectLabels(cr, &env.SmartRouter, getFormattedComponentName(cr, constants.Smartrouter))
+	setObjectLabels(cr, &env.ProcessMigration, getFormattedComponentName(cr, constants.ProcessMigration))
+}
+
+func getConsoleName(cr *api.KieApp) string {
+	env := string(cr.Spec.Environment)
+	consoleName := ""
+	if strings.Contains(env, constants.RhdmPrefix) {
+		consoleName = constants.RhdmDecisionCentral
+	} else if strings.Contains(env, constants.RhpamPrefix) {
+
+		if strings.Contains(env, constants.Production) {
+			consoleName = constants.RhpamBusinessCentralMon
+		} else {
+			consoleName = constants.RhpamBusinessCentral
+		}
+	}
+	return consoleName
 }
 
 func getSubComponentTypeByImageName(imageName string) string {
-	retValue := "application"
+	retValue := constants.SUBCOMPONENT_TYPE_APP
 	if imageName == constants.RhpamSmartRouterImageName || imageName == constants.RhpamControllerImageName ||
 		imageName == constants.RhdmSmartRouterImageName || imageName == constants.RhdmControllerImageName {
 
-		retValue = "infrastructure"
+		retValue = constants.SUBCOMPONENT_TYPE_INFRA
 	}
 	return retValue
 }
 
-func setObjectLabels(cr *api.KieApp, object *api.CustomObject) {
+func setObjectLabels(cr *api.KieApp, object *api.CustomObject, subcomponent string) {
 	for index, obj := range object.DeploymentConfigs {
-		subcomponent, _, _ := GetImage(object.DeploymentConfigs[index].Spec.Template.Spec.Containers[0].Image)
 		object.DeploymentConfigs[index].Spec.Template.Labels = setLabels(cr, obj.Spec.Template.Labels, subcomponent, getSubComponentTypeByImageName(subcomponent))
 	}
 	for index, obj := range object.StatefulSets {
-		subcomponent, _, _ := GetImage(object.StatefulSets[index].Spec.Template.Spec.Containers[0].Image)
 		object.StatefulSets[index].Spec.Template.Labels = setLabels(cr, obj.Spec.Template.Labels, subcomponent, getSubComponentTypeByImageName(subcomponent))
 	}
+}
 
+func setObjectLabelsForServer(cr *api.KieApp, object *api.CustomObject) {
+	for index, obj := range object.DeploymentConfigs {
+		subcomponent := getFormattedComponentName(cr, constants.KieServerServicePrefix)
+		object.DeploymentConfigs[index].Spec.Template.Labels = setLabels(cr, obj.Spec.Template.Labels, subcomponent, getSubComponentTypeByImageName(subcomponent))
+	}
+	for index, obj := range object.StatefulSets {
+		subcomponent := getFormattedComponentName(cr, constants.KieServerServicePrefix)
+		object.StatefulSets[index].Spec.Template.Labels = setLabels(cr, obj.Spec.Template.Labels, subcomponent, getSubComponentTypeByImageName(subcomponent))
+	}
+}
+
+func getFormattedComponentName(cr *api.KieApp, name string) string {
+	return getPrefixEnv(cr) + "-" + name + constants.RhelVersion
+}
+
+func getPrefixEnv(cr *api.KieApp) string {
+	prefix := constants.RhpamPrefix
+	if strings.HasPrefix(string(cr.Status.Applied.Environment), constants.RhdmPrefix) {
+		prefix = constants.RhdmPrefix
+	}
+	return prefix
 }
 
 func setLabels(cr *api.KieApp, labels map[string]string, subcomponent string, subcomponentType string) map[string]string {
@@ -251,7 +295,6 @@ func findCustomObjectByName(template api.CustomObject, objects []api.CustomObjec
 }
 
 func getEnvTemplate(cr *api.KieApp) (envTemplate api.EnvTemplate, err error) {
-
 	SetDefaults(cr)
 	serversConfig, err := getServersConfig(cr)
 	if err != nil {
@@ -263,6 +306,9 @@ func getEnvTemplate(cr *api.KieApp) (envTemplate api.EnvTemplate, err error) {
 		SmartRouter: getSmartRouterTemplate(cr),
 		Constants:   *getTemplateConstants(cr),
 	}
+	if IsOcpCA(cr) {
+		envTemplate.OpenshiftCaBundle = cr.Status.Applied.Truststore.OpenshiftCaBundle
+	}
 
 	dashbuilderTemplate, err := getDashbuilderTemplate(cr, serversConfig, &envTemplate.Console)
 	if err != nil {
@@ -392,6 +438,7 @@ func getConsoleTemplate(cr *api.KieApp) api.ConsoleTemplate {
 		}
 
 		// JVM configuration
+		cr.Status.Applied.Objects.Console.Jvm = setCAJavaAppend(cr, cr.Status.Applied.Objects.Console.Jvm)
 		if cr.Status.Applied.Objects.Console.Jvm != nil {
 			template.Jvm = *cr.Status.Applied.Objects.Console.Jvm.DeepCopy()
 		}
@@ -454,6 +501,7 @@ func getDashbuilderTemplate(cr *api.KieApp, serversConfig []api.ServerTemplate,
 		applyDashbuilderConfig(dashbuilderTemplate, *cr, serversConfig, console)
 
 		// JVM configuration
+		cr.Status.Applied.Objects.Dashbuilder.Jvm = setCAJavaAppend(cr, cr.Status.Applied.Objects.Dashbuilder.Jvm)
 		if cr.Status.Applied.Objects.Dashbuilder.Jvm != nil {
 			dashbuilderTemplate.Jvm = *cr.Status.Applied.Objects.Dashbuilder.Jvm.DeepCopy()
 		}
@@ -549,6 +597,11 @@ func getSmartRouterTemplate(cr *api.KieApp) api.SmartRouterTemplate {
 			template.ImageURL = template.ImageContext + "/" + template.Image + ":" + template.ImageTag
 			template.OmitImageStream = false
 		}
+		// JVM configuration
+		cr.Status.Applied.Objects.SmartRouter.Jvm = setCAJavaAppend(cr, cr.Status.Applied.Objects.SmartRouter.Jvm)
+		if cr.Status.Applied.Objects.SmartRouter.Jvm != nil {
+			template.Jvm = *cr.Status.Applied.Objects.SmartRouter.Jvm.DeepCopy()
+		}
 	}
 	return template
 }
@@ -606,14 +659,29 @@ func serverSortBlanks(serverSets []api.KieServerSet) []api.KieServerSet {
 	return newSets
 }
 
+func setCAJavaAppend(cr *api.KieApp, jvm *api.JvmObject) *api.JvmObject {
+	if IsOcpCA(cr) {
+		if jvm == nil {
+			jvm = &api.JvmObject{}
+		}
+		for _, caOption := range caOptsAppend {
+			if !strings.Contains(jvm.JavaOptsAppend, caOption) {
+				jvm.JavaOptsAppend = strings.Join([]string{jvm.JavaOptsAppend, caOption}, " ")
+			}
+		}
+		jvm.JavaOptsAppend = strings.TrimSpace(jvm.JavaOptsAppend)
+	}
+	return jvm
+}
+
 // Returns the templates to use depending on whether the spec was defined with a common configuration
 // or a specific one.
 func getServersConfig(cr *api.KieApp) ([]api.ServerTemplate, error) {
 	var servers []api.ServerTemplate
-	serverReplicas := Pint32(1)
+	serverReplicas := int32(1)
 	envConstants, hasEnv := constants.EnvironmentConstants[cr.Status.Applied.Environment]
 	if hasEnv {
-		serverReplicas = &envConstants.Replica.Server.Replicas
+		serverReplicas = envConstants.Replica.Server.Replicas
 	}
 	product := GetProduct(cr.Status.Applied.Environment)
 	usedNames := map[string]bool{}
@@ -635,6 +703,7 @@ func getServersConfig(cr *api.KieApp) ([]api.ServerTemplate, error) {
 				Build:            getBuildConfig(product, cr, serverSet),
 				KeystoreSecret:   serverSet.KeystoreSecret,
 				StorageClassName: serverSet.StorageClassName,
+				JbpmCluster:      serverSet.JbpmCluster,
 			}
 
 			if cr.Status.Applied.Objects.Console == nil || cr.Status.Applied.Environment == api.RhdmProductionImmutable {
@@ -643,7 +712,7 @@ func getServersConfig(cr *api.KieApp) ([]api.ServerTemplate, error) {
 			if serverSet.ID != "" {
 				template.KieServerID = serverSet.ID
 			}
-			if serverSet.Build != nil {
+			if serverSet.Build != nil && (len(serverSet.Build.ExtensionImageStreamTag) > 0 || len(serverSet.Build.GitSource.URI) > 0) {
 				if *serverSet.Deployments > 1 {
 					return []api.ServerTemplate{}, fmt.Errorf("Cannot request %v deployments for a build", *serverSet.Deployments)
 				}
@@ -660,7 +729,11 @@ func getServersConfig(cr *api.KieApp) ([]api.ServerTemplate, error) {
 
 			// Set replicas
 			if serverSet.Replicas == nil {
-				serverSet.Replicas = serverReplicas
+				serverSet.Replicas = &serverReplicas
+			}
+			// If JbpmCluster enabled and replicas set to 1, increase replicas to 2.
+			if serverSet.JbpmCluster && *serverSet.Replicas == int32(1) {
+				serverSet.Replicas = Pint32(2)
 			}
 			template.Replicas = *serverSet.Replicas
 
@@ -690,17 +763,22 @@ func getServersConfig(cr *api.KieApp) ([]api.ServerTemplate, error) {
 				template.Jms = *jmsConfig
 			}
 
-			instanceTemplate := template.DeepCopy()
-			if instanceTemplate.KeystoreSecret == "" {
-				instanceTemplate.KeystoreSecret = fmt.Sprintf(constants.KeystoreSecret, instanceTemplate.KieName)
+			getKafkaConfig(serverSet.Kafka)
+			if serverSet.Kafka != nil {
+				template.Kafka = serverSet.Kafka
+			}
+
+			if template.KeystoreSecret == "" {
+				template.KeystoreSecret = fmt.Sprintf(constants.KeystoreSecret, template.KieName)
 			}
 
 			// JVM configuration
+			serverSet.Jvm = setCAJavaAppend(cr, serverSet.Jvm)
 			if serverSet.Jvm != nil {
-				instanceTemplate.Jvm = *serverSet.Jvm.DeepCopy()
+				template.Jvm = *serverSet.Jvm.DeepCopy()
 			}
 
-			servers = append(servers, *instanceTemplate)
+			servers = append(servers, template)
 		}
 
 	}
@@ -841,6 +919,8 @@ func getBuildConfig(product string, cr *api.KieApp, serverSet *api.KieServerSet)
 			GitHubWebhookSecret:          getWebhookSecret(api.GitHubWebhook, serverSet.Build.Webhooks),
 			GenericWebhookSecret:         getWebhookSecret(api.GenericWebhook, serverSet.Build.Webhooks),
 			KieServerContainerDeployment: serverSet.Build.KieServerContainerDeployment,
+			DisablePullDeps:              serverSet.Build.DisablePullDeps,
+			DisableKCVerification:        serverSet.Build.DisableKCVerification,
 			MavenMirrorURL:               serverSet.Build.MavenMirrorURL,
 			ArtifactDir:                  serverSet.Build.ArtifactDir,
 		}
@@ -972,6 +1052,27 @@ func getJmsConfig(environment api.EnvironmentType, jms *api.KieAppJmsObject) (*a
 	return jms, nil
 }
 
+func getKafkaConfig(kafka *api.KafkaExtObject) {
+	if kafka != nil {
+		//if something is missing we set mandatory defaults
+		if kafka.MaxBlockMs == nil {
+			kafka.MaxBlockMs = Pint32(2000)
+		}
+		if len(kafka.BootstrapServers) == 0 {
+			kafka.BootstrapServers = "localhost:9092"
+		}
+		if len(kafka.GroupID) == 0 {
+			kafka.GroupID = "jbpm-consumer"
+		}
+		if kafka.Acks == nil {
+			kafka.Acks = Pint(1)
+		}
+		if kafka.AutocreateTopics == nil {
+			kafka.AutocreateTopics = Pbool(true)
+		}
+	}
+}
+
 func getDefaultQueue(append bool, defaultJmsQueue string, jmsQueue string) string {
 	if append {
 		if jmsQueue == "" {
@@ -1228,6 +1329,7 @@ func SetDefaults(cr *api.KieApp) {
 	}
 
 	if specApply.Objects.SmartRouter != nil {
+		checkJvmOnSmartRouter(specApply.Objects.SmartRouter)
 		setResourcesDefault(&specApply.Objects.SmartRouter.KieAppObject, constants.SmartRouterLimits, constants.SmartRouterRequests)
 	}
 
@@ -1262,6 +1364,13 @@ func checkJvmOnDashbuilder(dashbuilder *api.DashbuilderObject) {
 	setJvmDefault(dashbuilder.Jvm)
 }
 
+func checkJvmOnSmartRouter(smartrouter *api.SmartRouterObject) {
+	if smartrouter.Jvm == nil {
+		smartrouter.Jvm = &api.JvmObject{}
+	}
+	setJvmDefault(smartrouter.Jvm)
+}
+
 func checkJvmOnServer(server *api.KieServerSet) {
 	if server.Jvm == nil {
 		server.Jvm = &api.JvmObject{}
@@ -1496,6 +1605,30 @@ func mergeDashbuilder(service kubernetes.PlatformService, cr *api.KieApp, env ap
 	return env, nil
 }
 
+func overrideKafkaTopicsEnv(cr *api.KieApp, env *api.Environment) {
+	var topics []string
+	for index, server := range cr.Status.Applied.Objects.Servers {
+		if server.Kafka != nil {
+			for _, mapping := range server.Kafka.Topics {
+				topics = append(topics, mapping)
+			}
+			//We set a comma as a separator between topics' mappings
+			setKafkaTopics(&env.Servers[index], strings.Join(topics, ","))
+		}
+	}
+}
+
+func setKafkaTopics(object *api.CustomObject, value string) {
+	for index := range object.DeploymentConfigs {
+		for indexEnv, env := range object.DeploymentConfigs[index].Spec.Template.Spec.Containers[index].Env {
+			if env.Name == constants.KafkaTopicsEnv {
+				object.DeploymentConfigs[index].Spec.Template.Spec.Containers[index].Env[indexEnv] = corev1.EnvVar{Name: constants.KafkaTopicsEnv, Value: value}
+				return
+			}
+		}
+	}
+}
+
 func loadProcessMigrationFromFile(filename string, service kubernetes.PlatformService, cr *api.KieApp, envTemplate api.EnvTemplate) (api.Environment, error) {
 	var pimEnv api.Environment
 	yamlBytes, err := loadYaml(service, filename, cr.Status.Applied.Version, cr.Namespace, envTemplate)
@@ -1560,6 +1693,12 @@ func isGE710(cr *api.KieApp) bool {
 	return semver.Compare(semver.MajorMinor("v"+cr.Status.Applied.Version), "v7.10") >= 0
 }
 
+func IsOcpCA(cr *api.KieApp) bool {
+	return cr.Status.Applied.Truststore != nil &&
+		cr.Status.Applied.Truststore.OpenshiftCaBundle &&
+		semver.Compare(semver.MajorMinor("v"+cr.Status.Applied.Version), "v7.11") >= 0
+}
+
 func getDatabaseDeploymentTemplate(cr *api.KieApp, serversConfig []api.ServerTemplate,
 	processMigrationTemplate *api.ProcessMigrationTemplate) []api.DatabaseTemplate {
 	var databaseDeploymentTemplate []api.DatabaseTemplate
