@@ -315,7 +315,7 @@ func main() {
 		if csv.Maturity == "test" {
 			bundleDir = "deploy/olm-catalog/test/" + *ver + "/"
 		}
-		csvFile := bundleDir + "manifests/" + operatorName + "." + *ver + ".clusterserviceversion.yaml"
+		csvFile := bundleDir + "manifests/" + operatorName + ".clusterserviceversion.yaml"
 
 		var templateInterface interface{}
 		templateInterface = templateStruct
@@ -335,17 +335,6 @@ func main() {
 		}
 		createFile(csvFile, &templateInterface)
 
-		// copy crd to manifests dir
-		crdYaml := "kieapp.crd.yaml"
-		crdPath := "deploy/crds/"
-		crdFile := crdPath + crdYaml
-		err = CopyFile(crdFile, bundleDir+"manifests/"+crdYaml)
-		if err != nil {
-			log.Error(err)
-		}
-		//crdSymLink := bundleDir + "manifests/" + crdYaml
-		//os.Symlink("../../../../crds/"+crdYaml, crdSymLink)
-
 		annotationsdata := annotationsStruct{
 			Annotations: map[string]string{
 				"operators.operatorframework.io.bundle.channel.default.v1": channel,
@@ -385,7 +374,7 @@ func main() {
 		if jsonByte, err = sjson.DeleteBytes(jsonByte, "spec"); err != nil {
 			log.Error(err)
 		}
-		if jsonByte, err = sjson.SetBytes(jsonByte, "spec.version", []byte(constants.PriorVersion1)); err != nil {
+		if jsonByte, err = sjson.SetBytes(jsonByte, "spec.version", []byte(constants.PriorVersion)); err != nil {
 			log.Error(err)
 		}
 		var snippetObj interface{}
